@@ -2,6 +2,7 @@ from defaults import *
 
 try:
     import gconf
+    import gobject
 except ImportError:
     haveGConfSupport = False
     _notifiers = {}
@@ -17,7 +18,7 @@ except ImportError:
         print 'Configuration at ' + CONFIG_FILE + ' is invalid, ignoring'
     else:
         print 'Loading configuration from ' + CONFIG_FILE
-        
+
     def _bool(string):
         return string == 'True'
         
@@ -51,7 +52,10 @@ else:
     haveGConfSupport = True
     _GCONF_DIR = '/apps/glchess/'
     _config = gconf.client_get_default()
-    _config.add_dir(_GCONF_DIR[:-1], gconf.CLIENT_PRELOAD_NONE)
+    try:
+        _config.add_dir(_GCONF_DIR[:-1], gconf.CLIENT_PRELOAD_NONE)
+    except gobject.GError:
+        pass
     
     _gconfGetFunction = {gconf.VALUE_BOOL: gconf.Value.get_bool,
                          gconf.VALUE_FLOAT: gconf.Value.get_float,
@@ -74,6 +78,9 @@ _defaults = {'show_toolbar':                     True,
              'move_format':                      'human',
              'promotion_type':                   'queen',
              'board_view':                       'human',
+             'show_comments':                    False,
+             'show_numbering':                   False,
+             'enable_networking':                True,
              'load_directory':                   '',
              'save_directory':                   '',
              'new_game_dialog/move_time':        0,
@@ -94,7 +101,11 @@ def get(name):
     Raises an Error exception if the value does not exist.
     """
     if haveGConfSupport:
-        entry = _config.get(_GCONF_DIR + name)
+        try:
+            entry = _config.get(_GCONF_DIR + name)
+        except gobject.GError:
+            entry = None
+        
         if entry is None:
             try:
                 return _defaults[name]
@@ -128,8 +139,11 @@ def set(name, value):
             function = _gconfSetFunction[type(value)]
         except KeyError:
             raise TypeError('Only config values of type: int, str, float, bool supported')
-        
-        function(_GCONF_DIR + name, value)
+        else:
+            try:
+                function(_GCONF_DIR + name, value)
+            except gobject.GError:
+                pass
 
     else:
         # Debounce
@@ -165,16 +179,16 @@ def watch(name, function):
     """
     """
     if haveGConfSupport:
-        _config.notify_add(_GCONF_DIR + name, _watch, (function, name))
+        try:
+            _config.notify_add(_GCONF_DIR + name, _watch, (function, name))
+        except gobject.GError:
+            pass
     else:
         try:
             watchers = _notifiers[name]
         except KeyError:
-            watchers = []
-            
+            watchers = _notifiers[name] = []            
         watchers.append(function)
-            
-        _notifiers[name] = watchers
 
 def _save():
     """Save the current configuration"""
