@@ -50,8 +50,8 @@ prompt for usage and a list of options.
 """
 
 
-__revision__ = '$Rev: 7653 $'
-__date__ = '$Date: 2008-05-14 13:45:25 +0200 (Wed, 14 May 2008) $'
+__revision__ = '$Rev: 7818 $'
+__date__ = '$Date: 2008-08-14 15:58:17 +0200 (Thu, 14 Aug 2008) $'
 __author__ = '$Author: rancell $'
 
 
@@ -699,7 +699,7 @@ class Reader:
             try:
                 tag, data = self.read_chunk()
             except ValueError, e:
-                raise Error('Chunk error: ' + e.args[0])
+                raise Error('Chunk error: ' + e.message)
 
             # print >> sys.stderr, tag, len(data)
             if tag == 'IHDR': # http://www.w3.org/TR/PNG/#11IHDR
