@@ -725,7 +725,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
-	adj = gtk_adjustment_new (t->startingLevel, 1, 20, 1, 5, 20);
+	adj = gtk_adjustment_new (t->startingLevel, 1, 20, 1, 5, 0);
 	t->sentry = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 10.0, 0);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (t->sentry),
 					   GTK_UPDATE_ALWAYS);
@@ -1372,7 +1372,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 {
 	Tetris *t = (Tetris*) d;
 
-	const gchar * const authors[] = { "J. Marcin Gorycki", NULL };
+	const gchar * const authors[] = { "Gnome Games Team", NULL };
 
 	const gchar * const documenters[] = { "Angela Boyle", NULL };
 
@@ -1386,7 +1386,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 #endif
 			       "version", VERSION,
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
-			       "copyright", "Copyright \xc2\xa9 1999-2008 J. Marcin Gorycki",
+			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2008 Others",
 			       "license", license,
 		               "website-label", _("GNOME Games web site"),
 			       "authors", authors,
